package cn.com.countrygarden.bi.main.dao.experience;

import cn.com.countrygarden.bi.main.dto.experience.WcxExperContentDto;
import cn.com.countrygarden.bi.main.dto.experience.WcxMyPublishContentDto;
import cn.com.countrygarden.bi.main.dto.experience.WcxPublishContentDto;
import cn.com.countrygarden.bi.main.model.experience.WcxPublishFile;
import cn.com.countrygarden.bi.main.model.experience.WcxPublishMessage;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

@Mapper
public interface TygGzhH5Mapper {
    List<WcxExperContentDto> selectListByPhone(@Param("phone") String phone, @Param("size")int size, @Param("page")int page);

    int selectCountByPhone(String phone);

    void save(WcxPublishMessage publishMessage);

    void saveFile(List<WcxPublishFile> fileList);

    WcxMyPublishContentDto info(WcxPublishContentDto dto);

    List<WcxMyPublishContentDto> myInfo(WcxPublishContentDto dto);

    int deletePublishMessage(@Param("deleted") int deleted,@Param("id") Long id);

    int deletePublishFile(@Param("deleted") int deleted,@Param("publishNo") String publishNo);


    int selectCount(WcxPublishContentDto dto);

    void updateAccount(WcxPublishContentDto dto);

    void updateAccountByphone(@Param("account")int i3, @Param("id")Long id);
}
